Learn R Programming

iBBiG (version 1.16.0)

iBBiG-package: iBBiG performs bi-clustering of binary matrices

Description

iBBiG is a bi-clustering algorithm, optimized for module discovery in sparse noisy binary genomics data. We designed iBBiG to have high specificity and thereby minimize the false positive rate when discovering new classes; the iterative approach employed in iBBiG is able to discover weak signals, even if they are potentially masked by stronger ones.

Arguments

Details

Package:
iBBiG
Type:
Package
Version:
0.99.1
Date:
2012-03-15
License:
Free Artistic
LazyLoad:
yes
Depends:
methods
The main functions is iBBiG. This is the biclustering algorithm.

References

Daniel Gusenleitner, Eleanor A Howe, Stefan Bentink, John Quackenbush and Aedin C Culhane iBBiG: Iterative Binary Bi-clustering of Gene Sets Bioinformatics. In review.

See Also

Also see biclust ~~

Examples

Run this code


#create simulated datasets
binMat<-makeArtificial()
binMat
plot(binMat)
res<- try(iBBiG(binMat@Seeddata, nModules=10))
plot(res)
res

## Subset a cluster

res[4]
res[1:2]


## As iBBiG extends the class Biclust can use Biclust functions on it
## View the rows and columns of an iBBiG object

## Create a list of matrices, one for each cluster
Modules<-bicluster(res@Seeddata, res)
length(Modules)
lapply(Modules, dim)


# Or extract a list of a specific cluster
M1<-bicluster(res@Seeddata, res, 1)
dim(M1[[1]])
str(M1)
M1[[1]][1:5,1:3]

Run the code above in your browser using DataLab